Welcome to Django Horizon's documentation!
==========================================

.. include:: ../README.rst
.. include:: ../AUTHORS.rst

Contents:

.. toctree::
   :maxdepth: 2

   contributing
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
